# PythonEnvironmentsEnvironment

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**os_name** | **str** | Operating system name |
**os_version** | **str** | Operating system version |
**python_version** | **str** | Python version |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

